@@ -15,11 +15,9 @@ DictionaryPreferenceDialog::DictionaryPreferenceDialog(QWidget *parent, const QS
 {
 }
 
-DictionaryPreferenceDialog::~DictionaryPreferenceDialog()
-{
-}
-
 QString DictionaryPreferenceDialog::name() const
 {
     return m_name;
 }
+
+#include "moc_dictionarypreferencedialog.cpp"
