@@ -13,9 +13,7 @@
 #include "ui_radselectprefdialog.h"
 
 #include <KActionCollection>
-#include <KConfig>
 #include <KConfigDialog>
-#include <KLocalizedString>
 #include <KStandardAction>
 #include <KStandardShortcut>
 #include <KXMLGUIFactory>
@@ -23,7 +21,6 @@
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusMessage>
-#include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QMimeData>
 #include <QStatusBar>
@@ -48,7 +45,7 @@ RadSelect::RadSelect()
     // automatically save settings if changed: window size, toolbar
     // position, icon size, etc.  Also to add actions for the statusbar
     // toolbar, and keybindings if necessary.
-    setupGUI(Default, QStringLiteral("radselectui.rc"));
+    setupGUI(Keys | StatusBar | Save | Create, QStringLiteral("radselectui.rc"));
 
     // allow the view to change the statusbar
     connect(m_view, &RadSelectView::signalChangeStatusbar, this, &RadSelect::changeStatusbar);
@@ -86,7 +83,7 @@ void RadSelect::dropEvent(QDropEvent *event)
 {
     QByteArray qba = event->mimeData()->data(QStringLiteral("text/plain"));
     if (qba.size() > 0) {
-        loadSearchString(qba);
+        loadSearchString(QString::fromUtf8(qba));
     }
 }
 
@@ -108,10 +105,11 @@ void RadSelect::optionsPreferences()
     }
 
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), RadSelectConfigSkeleton::self());
+    dialog->setFaceType(KPageDialog::FaceType::Plain);
     auto preferences = new QWidget();
     Ui::radselectprefdialog layout;
     layout.setupUi(preferences);
-    dialog->addPage(preferences, i18n("Settings"), QStringLiteral("help-contents"));
+    dialog->addPage(preferences, QString(), QStringLiteral("help-contents"));
     connect(dialog, SIGNAL(settingsChanged(QString)), m_view, SLOT(loadSettings()));
     dialog->show();
 }
